@@ -9,7 +9,7 @@ use FileHandle;
 use Digest::MD5;
 use Encode;
 
-$VERSION = "4.00";
+$VERSION = "4.01";
 
 # These are the recognized field names for a SID file. They must appear in
 # the order they appear in a SID file.
@@ -2096,21 +2096,37 @@ Overload '=' so two objects can be assigned to each other?
 
 =back
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+MIT License
 
-Audio::SID Perl module - Copyright (C) 1999-2017 LaLa <LaLa@C64.org>
+Copyright 2017 LaLa (Imre Olajos)
 
-(Thanks to Adam Lorentzon for showing me how to extract binary data from SID
-files! :-)
+Permission is hereby granted, free of charge, to any person obtaining a copy of
+this software and associated documentation files (the "Software"), to deal in
+the Software without restriction, including without limitation the rights to
+use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
+the Software, and to permit persons to whom the Software is furnished to do so,
+subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
+FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
+COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 SID MD5 calculation - Copyright (C) 2001 Michael Schwendt <sidplay@geocities.com>
 
+Thanks to Adam Lorentzon for showing me how to extract binary data from SID
+files! :-)
+
 =head1 VERSION
 
-Version v4.00, released to CPAN on ???.
+Version v4.01, released to CPAN on July 12, 2017.
 
 First version (then called Audio::PSID) created on June 11, 1999.
 
